@@ -9,6 +9,7 @@ from openpyxl.worksheet import Worksheet
 from openpyxl.worksheet.read_only import ReadOnlyWorksheet
 from openpyxl.worksheet.copier import WorksheetCopy
 
+from openpyxl.utils import quote_sheetname
 from openpyxl.utils.indexed_list import IndexedList
 from openpyxl.utils.datetime  import CALENDAR_WINDOWS_1900
 from openpyxl.utils.exceptions import ReadOnlyWorkbookException
@@ -19,6 +20,14 @@ from openpyxl.writer.excel import save_workbook
 from openpyxl.styles.cell_style import StyleArray
 from openpyxl.styles.named_styles import NamedStyle
 from openpyxl.styles.differential import DifferentialStyleList
+from openpyxl.styles.alignment import Alignment
+from openpyxl.styles.borders import DEFAULT_BORDER
+from openpyxl.styles.fills import DEFAULT_EMPTY_FILL, DEFAULT_GRAY_FILL
+from openpyxl.styles.fonts import DEFAULT_FONT
+from openpyxl.styles.protection import Protection
+from openpyxl.styles.colors import COLOR_INDEX
+from openpyxl.styles.named_styles import NamedStyleList
+from openpyxl.styles.table import TableStyleList
 
 from openpyxl.chartsheet import Chartsheet
 from .defined_name import DefinedName, DefinedNameList
@@ -73,13 +82,6 @@ class Workbook(object):
 
     def _setup_styles(self):
         """Bootstrap styles"""
-        from openpyxl.styles.alignment import Alignment
-        from openpyxl.styles.borders import DEFAULT_BORDER
-        from openpyxl.styles.fills import DEFAULT_EMPTY_FILL, DEFAULT_GRAY_FILL
-        from openpyxl.styles.fonts import DEFAULT_FONT
-        from openpyxl.styles.protection import Protection
-        from openpyxl.styles.colors import COLOR_INDEX
-        from openpyxl.styles.named_styles import NamedStyleList
 
         self._fonts = IndexedList()
         self._fonts.add(DEFAULT_FONT)
@@ -101,6 +103,7 @@ class Workbook(object):
         self._cell_styles = IndexedList([StyleArray()])
         self._named_styles = NamedStyleList()
         self.add_named_style(NamedStyle(font=DEFAULT_FONT, builtinId=0))
+        self._table_styles = TableStyleList()
 
 
     @property
@@ -264,7 +267,7 @@ class Workbook(object):
         """Create a new named_range on a worksheet"""
         defn = DefinedName(name=name, localSheetId=scope)
         if worksheet is not None:
-            defn.value = "{0}!{1}".format(worksheet.title, value)
+            defn.value = "{0}!{1}".format(quote_sheetname(worksheet.title), value)
         else:
             defn.value = value
 
